#!/bin/sh

init_dev() {

echo "====================================================================="

if [ -d /sys/bus/i2c/drivers/mt9v032/?-00* ]; then
	CAMERA="VM-010(mt9v024)"
	CAM_DRIVER="mt9v032"
	CAM_I2C_ADRESS=$(find /sys/bus/i2c/drivers/mt9v032/ -name "?-00*" | cut -d / -f 7 | cut -c5-6)
	CAM_I2C_BUS=$(find /sys/bus/i2c/drivers/mt9v032/ -name "?-00*" | cut -d / -f 7 | cut -c1-1)
elif [ -d /sys/bus/i2c/drivers/mt9p031/?-00* ]; then
	CAMERA="VM-011(mt9p031_mt9p006)"
	CAM_DRIVER="mt9p031"
	CAM_I2C_ADRESS=$(find /sys/bus/i2c/drivers/mt9p031/ -name "?-00*" | cut -d / -f 7 | cut -c5-6)
	CAM_I2C_BUS=$(find /sys/bus/i2c/drivers/mt9p031/ -name "?-00*" | cut -d / -f 7 | cut -c1-1)
elif [ -d /sys/bus/i2c/drivers/mt9m001/?-00* ]; then
	CAMERA="VM-006(mt9m001)"
	CAM_DRIVER="mt9m001"
	CAM_I2C_ADRESS=$(find /sys/bus/i2c/drivers/mt9m001/ -name "?-00*" | cut -d / -f 7 | cut -c5-6)
	CAM_I2C_BUS=$(find /sys/bus/i2c/drivers/mt9m001/ -name "?-00*" | cut -d / -f 7 | cut -c1-1)
elif [ -d /sys/bus/i2c/drivers/mt9m111/?-00* ]; then
	CAMERA="VM-009(mt9m131)"
	CAM_DRIVER="mt9m111"
	CAM_I2C_ADRESS=$(find /sys/bus/i2c/drivers/mt9m111/ -name "?-00*" | cut -d / -f 7 | cut -c5-6)
	CAM_I2C_BUS=$(find /sys/bus/i2c/drivers/mt9m111/ -name "?-00*" | cut -d / -f 7 | cut -c1-1)
elif [ -d /sys/bus/i2c/drivers/tw9910/?-00* ]; then
	CAMERA="VM-008(tw9910)"
	CAM_DRIVER="tw9910"
	CAM_I2C_ADRESS=$(find /sys/bus/i2c/drivers/tw9910/ -name "?-00*" | cut -d / -f 7 | cut -c5-6)
	CAM_I2C_BUS=$(find /sys/bus/i2c/drivers/tw9910/ -name "?-00*" | cut -d / -f 7 | cut -c1-1)
elif [ -d /sys/bus/i2c/drivers/phytec-vm012/?-00* ]; then
	CAMERA="VM-012(vita1300)"
	CAM_DRIVER="vm012"
	CAM_I2C_ADRESS=$(find /sys/bus/i2c/drivers/phytec-vm012/ -name "?-00*" | cut -d / -f 7 | cut -c5-6)
	CAM_I2C_BUS=$(find /sys/bus/i2c/drivers/phytec-vm012/ -name "?-00*" | cut -d / -f 7 | cut -c1-1)
elif [ -d /sys/bus/i2c/drivers/ar0144/?-00* ]; then
	CAMERA="VM-016(ar0144)"
	CAM_DRIVER="ar0144"
	CAM_I2C_ADRESS=$(find /sys/bus/i2c/drivers/ar0144/ -name "?-00*" | cut -d / -f 7 | cut -c5-6)
	CAM_I2C_BUS=$(find /sys/bus/i2c/drivers/ar0144/ -name "?-00*" | cut -d / -f 7 | cut -c1-1)
else
	echo "no camera driver loaded"
	echo "please check camera device tree"
	echo ""
	return 1
fi

echo "camera = $CAMERA at i2c bus=$CAM_I2C_BUS with i2c adress=0x$CAM_I2C_ADRESS installed"
CAM_ENTITY_NUMBER=`media-ctl -p | grep " $CAM_DRIVER" | awk '{print $3}'`
CAM_DEVICE=$(media-ctl -e "$CAM_DRIVER $CAM_I2C_BUS-00$CAM_I2C_ADRESS")
if [ "$CAM_DRIVER" = "vm012" ]; then CAM_DEVICE=$(media-ctl -e "$CAM_DRIVER@$CAM_I2C_ADRESS")
fi
IPU1_CSI0_DEVICE=$(media-ctl -e "ipu1_csi0 capture")
IPU2_CSI1_DEVICE=$(media-ctl -e "ipu2_csi1 capture")

if [ "$CAM_ENTITY_NUMBER" = "" ]; then
	echo "camera not found"
	echo "please check connected camera type, i2c adress and cable connections"
	echo ""
	return 1
fi
echo " camera entity name = $CAM_ENTITY_NUMBER"
echo " camera subdevice name = $CAM_DEVICE"
echo " ipu1_csi0 capture device name = $IPU1_CSI0_DEVICE"
echo " ipu2_csi1 capture device name = $IPU2_CSI1_DEVICE"
echo " camera driver = $CAM_DRIVER"
echo ""
return 0
}

guess_param() {
	COL_FORMAT="bayer,format=grbg,depth=8"
	BAYER_CONVERT=" bayer2rgb !"
	NUMBER_OF_PIC="3"
	NORM=""
	REMAPPER=""
	V4L2_CTRL_CAM0=""
	V4L2_CTRL_CAM1=""
#	COL_FORMAT_XV="yuv"
#	COL_FORMAT_SCALE="yuv"
#	RAW_COL_FORMAT="rgb"
	if [ $CAMERA = "VM-010(mt9v024)" ]; then
		FRAME_SIZE=",width=752,height=480"
		FRAME_SIZE_LIVE_DEMO=",width=752,height=480"
		REG_SET_FILE="$(dirname $0)/register-settings-mt9v02x.txt"
		SENSOR_RES="752x480"
		SENSOR_RES_LIVE_DEMO="752x480"
		GRAB_RES="752x480"
		OFFSET_SENSOR="1,5"
		CAM_BW_FMT="Y8"
		CAM_COL_FMT="SGRBG8_1X8"
		COL_FORMAT="bayer,format=grbg,depth=8"
		BAYER_CONVERT=" bayer2rgbneon !"
		V4L2_CTRL_CAM0='v4l2-ctl -d '$IPU1_CSI0_DEVICE' -c row_noise_correction=1'
		V4L2_CTRL_CAM1='v4l2-ctl -d '$IPU2_CSI1_DEVICE' -c row_noise_correction=1'
	elif [ $CAMERA = "VM-011(mt9p031_mt9p006)" ]; then
		FRAME_SIZE=",width=2592,height=1944"
		FRAME_SIZE_LIVE_DEMO=",width=640,height=480"
		REG_SET_FILE="$(dirname $0)/register-settings-mt9p031.txt"
		SENSOR_RES="2592x1944"
		SENSOR_RES_LIVE_DEMO="2560x1920"
		GRAB_RES="640x480"
		OFFSET_SENSOR="16,54"
		CAM_BW_FMT="Y8"
		CAM_COL_FMT="SGRBG8_1X8"
		COL_FORMAT="bayer,format=grbg,depth=8"
		BAYER_CONVERT=" bayer2rgbneon !"
		V4L2_CTRL_CAM0='v4l2-ctl -d '$IPU1_CSI0_DEVICE' -c exposure=480,gain=32'
		V4L2_CTRL_CAM1='v4l2-ctl -d '$IPU2_CSI1_DEVICE' -c exposure=480,gain=32'
	elif [ $CAMERA = "VM-006(mt9m001)" ]; then
		FRAME_SIZE=",width=1280,height=1024"
		FRAME_SIZE_LIVE_DEMO=",width=1280,height=1024"
		REG_SET_FILE="$(dirname $0)/register-settings-mt9m001.txt"
		SENSOR_RES="1280x1024"
		SENSOR_RES_LIVE_DEMO="1280x1024"
		GRAB_RES="1280x1024"
		OFFSET_SENSOR="20,12"
		CAM_BW_FMT="Y8"
	elif [ $CAMERA = "VM-009(mt9m131)" ]; then
		FRAME_SIZE=",width=1280,height=1024"
		FRAME_SIZE_LIVE_DEMO=",width=1280,height=1024"
		REG_SET_FILE="$(dirname $0)/register-settings-mt9m131.txt"
		SENSOR_RES="1280x1024"
		SENSOR_RES_LIVE_DEMO="1280x1024"
		GRAB_RES="1280x1024"
		OFFSET_SENSOR="26,8"
		CAM_COL_FMT="YUYV8_2X8"
		COL_FORMAT="raw,format=UYVY"
		BAYER_CONVERT=""
		RAW_COL_FORMAT="rgb"
		COL_FORMAT_XV="yuv"
		COL_FORMAT_SCALE="yuv"
		V4L2_CTRL_CAM0='v4l2-ctl -d '$IPU1_CSI0_DEVICE' -c auto_exposure=1'
		V4L2_CTRL_CAM1='v4l2-ctl -d '$IPU2_CSI1_DEVICE' -c auto_exposure=1'
	elif [ $CAMERA = "VM-008(tw9910)" ]; then
		FRAME_SIZE=",width=720,height=576"
		FRAME_SIZE_LIVE_DEMO=",width=720,height=576"
		REG_SET_FILE="$(dirname $0)/register-settings-tw9910.txt"
		SENSOR_RES="720x576"
		SENSOR_RES_LIVE_DEMO="720x576"
		GRAB_RES="720x576"
		OFFSET_SENSOR="0,0"
		CAM_COL_FMT="YUYV8_2X8"
		COL_FORMAT="raw,format=UYVY"
		BAYER_CONVERT=""
		RAW_COL_FORMAT="rgb"
		COL_FORMAT_XV="yuv"
		COL_FORMAT_SCALE="yuv"
		NUMBER_OF_PIC="4"
		NORM="norm=PAL"
	elif [ $CAMERA = "VM-012(vita1300)" ]; then
		FRAME_SIZE=",width=1280,height=1024"
		FRAME_SIZE_LIVE_DEMO=",width=1280,height=960"
		REG_SET_FILE="$(dirname $0)/register-settings-vita1300.txt"
		SENSOR_RES="1280x1024"
		SENSOR_RES_LIVE_DEMO="1280x1024"
		GRAB_RES="1280x960"
		OFFSET_SENSOR="0,0"
		CAM_BW_FMT="Y8"
		CAM_COL_FMT="SRGGB8_1X8"
		COL_FORMAT="bayer,format=rggb,depth=8"
		BAYER_CONVERT=" bayer2rgbneon !"
		REMAPPER=" ! vita1300_remapper mode=0 passthrough=false"
		V4L2_CTRL_CAM0='v4l2-ctl -d '$IPU1_CSI0_DEVICE' -c subsampling=0'
		V4L2_CTRL_CAM1='v4l2-ctl -d '$IPU2_CSI1_DEVICE' -c subsampling=0'
	elif [ $CAMERA = "VM-016(ar0144)" ]; then
		FRAME_SIZE=",width=1280,height=800"
		FRAME_SIZE_LIVE_DEMO=",width=1280,height=800"
		REG_SET_FILE="$(dirname $0)/register-settings-ar0144.txt"
		SENSOR_RES="1280x800"
		SENSOR_RES_LIVE_DEMO="1280x800"
		GRAB_RES="1280x800"
		OFFSET_SENSOR="0,4"
		CAM_BW_FMT="Y8"
		CAM_COL_FMT="SGRBG8_1X8"
		COL_FORMAT="bayer,format=grbg,depth=8"
		BAYER_CONVERT=" bayer2rgbneon !"
		NUMBER_OF_PIC="5"
	else
		echo "No Camera found"
	fi
}
