#!/bin/sh
. `dirname $0`/../func.sh

init_dev
[ $? -ne 0 ] && exit 1

guess_param

echo 0 > /sys/class/graphics/fbcon/cursor_blink

echo "select resolution"
echo "================="
echo "1 = 1280 x 800 Full"
echo "2 = 1280 x 720 HD, with ROI"
echo "3 = 640  x 480 VGA, with ROI"
echo "4 = 640  x 400 with Skip2"
echo "5 = 640  x 400 with Skip2 and Binning (col/row average)"
echo "6 = 640  x 400 with Skip2 and Binning (col summed / row average)"
echo "7 = 320  x 200 with Skip4"
read RESOLUTION
echo "Your select = $RESOLUTION"
case $RESOLUTION in
  "1") SENSOR_RES="1280x800"; GRAB_RES="1280x800"; FRAME_SIZE=",width=1280,height=800"; OFFSET_SENSOR="(0,4)"; SCALE_SIZE=",width=640,height=400"; CTLS=( -c horizontal_skipping=0 -c vertical_skipping=0 -c row_binning=0 -c col_binning=0 ); KMS_SYNC="true";;
  "2") SENSOR_RES="1280x720"; GRAB_RES="1280x720"; FRAME_SIZE=",width=1280,height=720"; OFFSET_SENSOR="(0,44)"; SCALE_SIZE=",width=640,height=360"; CTLS=( -c horizontal_skipping=0 -c vertical_skipping=0 -c row_binning=0 -c col_binning=0  ); KMS_SYNC="true" ;;
  "3") SENSOR_RES="640x480"; GRAB_RES="640x480"; FRAME_SIZE=",width=640,height=480"; OFFSET_SENSOR="(320,164)"; SCALE_SIZE=",width=640,height=480"; CTLS=( -c horizontal_skipping=0 -c vertical_skipping=0 -c row_binning=0 -c col_binning=0  ); KMS_SYNC="true" ;;
  "4") SENSOR_RES="1280x800"; GRAB_RES="640x400"; FRAME_SIZE=",width=640,height=400"; OFFSET_SENSOR="(0,4)"; SCALE_SIZE=",width=640,height=400"; CTLS=( -c horizontal_skipping=1 -c vertical_skipping=1 -c row_binning=0 -c col_binning=0  ); KMS_SYNC="true" ;;
  "5") SENSOR_RES="1280x800"; GRAB_RES="640x400"; FRAME_SIZE=",width=640,height=400"; OFFSET_SENSOR="(0,4)"; SCALE_SIZE=",width=640,height=400"; CTLS=( -c horizontal_skipping=1 -c vertical_skipping=1 -c row_binning=1 -c col_binning=1  ); KMS_SYNC="true" ;;
  "6") SENSOR_RES="1280x800"; GRAB_RES="640x400"; FRAME_SIZE=",width=640,height=400"; OFFSET_SENSOR="(0,4)"; SCALE_SIZE=",width=640,height=400"; CTLS=( -c horizontal_skipping=1 -c vertical_skipping=1 -c row_binning=1 -c col_binning=2  ); KMS_SYNC="true" ;;
  "7") SENSOR_RES="1280x800"; GRAB_RES="320x200"; FRAME_SIZE=",width=320,height=200"; OFFSET_SENSOR="(0,4)"; SCALE_SIZE=",width=640,height=400"; CTLS=( -c horizontal_skipping=2 -c vertical_skipping=2 -c row_binning=0 -c col_binning=0  ); KMS_SYNC="true" ;;
  *) GRAB_RES="1280x800"; FRAME_SIZE=",width=1280,height=800"; OFFSET_SENSOR="(0,4)"; SCALE_SIZE=",width=640,height=480"; KMS_SYNC="true" ;;
esac

echo "starting gstreamer with $CAM_BW_FMT Source ..."
echo "read $FRAME_SIZE (offset x,y=$OFFSET_SENSOR) and write scaled to framebuffer $SCALE_SIZE"
echo "=============================================================="
echo ""
echo "configure IPU1_CSI0 (camera_0 port) with media_control"
echo "======================================================"

media-ctl -r
media-ctl -l ''$CAM_ENTITY_NUMBER'0->"ipu1_csi0_mux":1[1]'
media-ctl -l "'ipu1_csi0_mux':2->'ipu1_csi0':0[1]"
media-ctl -l "'ipu1_csi0':2->'ipu1_csi0 capture':0[1]"
#           Camera -> IPU1_CSI0_mux -> IPU1-CSI0 -> IPU1-CSI0 capture (/dev/videoX)

media-ctl -V ''$CAM_ENTITY_NUMBER'0 [fmt:Y8/'$GRAB_RES' '$OFFSET_SENSOR'/'$SENSOR_RES']'
media-ctl -V '"ipu1_csi0_mux":2 [fmt:Y8/'$GRAB_RES']'
media-ctl -V '"ipu1_csi0":2 [fmt:Y8/'$GRAB_RES']'

echo ""
echo " configure camera with v4l2_control"
echo " =================================="

v4l2-ctl "${CTLS[@]}" -d "$IPU1_CSI0_DEVICE"

echo ""
echo "start gstreamer, break with ctl-C"
echo "================================="

gst-launch-1.0 \
	v4l2src device=$IPU1_CSI0_DEVICE ! \
	video/x-raw,format=GRAY8,depth=8$FRAME_SIZE ! \
	videoscale ! \
	video/x-raw$SCALE_SIZE ! \
	videoconvert ! \
	queue ! kmssink driver-name="imx-drm" force-modesetting=false can-scale=false sync=$KMS_SYNC
#	fbdevsink sync=false

#	i2c file=`dirname $0`/../register-settings-ar0144.txt show=0 dev=$CAM_DEVICE ! \
#	Use the i2s plugin only for special register settings, that are not available through v4l2_control.

CTLS=( -c horizontal_skipping=0 -c vertical_skipping=0 -c row_binning=0 -c col_binning=0 )
v4l2-ctl "${CTLS[@]}" -d "$IPU1_CSI0_DEVICE"

echo 1 > /sys/class/graphics/fbcon/cursor_blink