#!/bin/sh

echo 0 > /sys/class/graphics/fbcon/cursor_blink

# check the set addresses in config-expansions file
CAM_I2C_ADRESS_0=$(media-ctl -p | grep -B 7 "> \"ipu1_csi0_mux\"" | grep vm012 | cut -c19-20)
CAM_I2C_ADRESS_1=$(media-ctl -p | grep -B 7 "> \"ipu2_csi1_mux\"" | grep vm012 | cut -c19-20)
CAM_I2C_BUS=$(find /sys/bus/i2c/drivers/phytec-vm012/ -name "?-00*" | cut -d / -f 7 | cut -c1-1 | sed 2d)

echo ""
echo " camera0 i2c address = $CAM_I2C_ADRESS_0"
echo " camera1 i2c address = $CAM_I2C_ADRESS_1"
echo " i2c bus address = $CAM_I2C_BUS"

# check the devices with "media-ctl -p"
IPU1_CSI0_DEVICE=$(media-ctl -e "ipu1_csi0 capture")
IPU2_CSI1_DEVICE=$(media-ctl -e "ipu2_csi1 capture")
CAM_DEVICE_0=$(media-ctl -e "vm012@$CAM_I2C_ADRESS_0")
CAM_DEVICE_1=$(media-ctl -e "vm012@$CAM_I2C_ADRESS_1")

echo " ipu1_csi0 capture device name = $IPU1_CSI0_DEVICE"
echo " ipu2_csi1 capture device name = $IPU2_CSI1_DEVICE"
echo " camera0 subdevice name = $CAM_DEVICE_0"
echo " camera1 subdevice name = $CAM_DEVICE_1"
echo ""
echo "starting gstreamer with two Bayer COLOR Sources ..."
echo "read camera_0 from IPU1_CSI0 and camera_1 from IPU2_CSI1 with 640 x 512 (skip)"
echo "scale both streams to 400x320 Pixel and write side by side into same framebuffer"
echo "================================================================================"
echo ""
echo "configure IPU1_CSI0 and IPU2_CSI1 with media_control"
echo "===================================================="

media-ctl -r
media-ctl -l "'vm012@$CAM_I2C_ADRESS_0':0->'ipu1_csi0_mux':1[1]"
media-ctl -l "'ipu1_csi0_mux':2->'ipu1_csi0':0[1]"
media-ctl -l "'ipu1_csi0':2->'ipu1_csi0 capture':0[1]"
#           Camera -> IPU1_CSI0_mux -> IPU1-CSI0 -> IPU1-CSI0 capture (/dev/videoX)

v4l2-ctl -d $IPU1_CSI0_DEVICE -c subsampling=1
# Note: Set subsampling is necessary before set resolution

media-ctl -V "'vm012@$CAM_I2C_ADRESS_0':0 [fmt:SRGGB8_1X8/640x512 (0,0)/640x512]"
media-ctl -V "'ipu1_csi0_mux':2 [fmt:SRGGB8_1X8/640x512]"
media-ctl -V "'ipu1_csi0':2 [fmt:SRGGB8_1X8/640x512]"

media-ctl -l "'vm012@$CAM_I2C_ADRESS_1':0->'ipu2_csi1_mux':1[1]"
media-ctl -l "'ipu2_csi1_mux':2->'ipu2_csi1':0[1]"
media-ctl -l "'ipu2_csi1':2->'ipu2_csi1 capture':0[1]"
#           Camera -> IPU1_CSI0_mux -> IPU1-CSI0 -> IPU1-CSI0 capture (/dev/videoX)

v4l2-ctl -d $IPU2_CSI1_DEVICE -c subsampling=1
# Note: Set subsampling is necessary before set resolution

media-ctl -V "'vm012@$CAM_I2C_ADRESS_1':0 [fmt:SRGGB8_1X8/640x512 (0,0)/640x512]"
media-ctl -V "'ipu2_csi1_mux':2 [fmt:SRGGB8_1X8/640x512]"
media-ctl -V "'ipu2_csi1':2 [fmt:SRGGB8_1X8/640x512]"

echo ""
echo "start gstreamer, break with ctl-C"
echo "================================="

gst-launch-1.0 videomixer name=mix  sink_0::xpos=0 sink_0::ypos=0 sink_1::xpos=400 sink_1::ypos=0 ! videoconvert ! queue ! kmssink driver-name="imx-drm" force-modesetting=false sync=false \
   v4l2src device=$IPU1_CSI0_DEVICE ! \
   video/x-bayer,format=rggb,depth=8,width=640,height=512,framerate=25/1 ! vita1300_remapper mode=2 passthrough=false ! bayer2rgbneon ! video/x-raw,width=640,height=512 ! \
   videoscale ! video/x-raw,width=400,height=320 ! videoconvert ! queue ! mix. \
   v4l2src device=$IPU2_CSI1_DEVICE ! \
   video/x-bayer,format=rggb,depth=8,width=640,height=512,framerate=25/1 ! vita1300_remapper mode=2 passthrough=false ! bayer2rgbneon ! video/x-raw,width=640,height=512 ! \
   videoscale ! video/x-raw,width=400,height=320 ! videoconvert ! queue ! mix.

#	Use the i2s plugin only for special register settings, that are not available through v4l2_control.
#i2c addr=0x$CAM_I2C_ADRESS_0 file=`dirname $0`/../../register-settings-vita1300.txt show=0 dev=$CAM_DEVICE_0 ! \
#i2c addr=0x$CAM_I2C_ADRESS_1 file=`dirname $0`/../../register-settings-vita1300.txt show=0 dev=$CAM_DEVICE_1 ! \

#gst-launch-1.0 \
#	v4l2src device=$IPU1_CSI0_DEVICE ! \
#	video/x-bayer,format=rggb,depth=8,depth=8,width=640,height=512 ! \
#	vita1300_remapper mode=2 passthrough=false ! \
#	bayer2rgbneon ! video/x-raw,width=640,height=512 ! \
#	videoscale ! \
#	video/x-raw,width=640,height=480 ! \
#	videoconvert ! \
#	queue ! kmssink driver-name="imx-drm" force-modesetting=false sync=true
##	fbdevsink sync=false

#	i2c addr=0x$CAM_I2C_ADRESS_0 file=`dirname $0`/../../register-settings-vita1300.txt show=0 dev=$CAM_DEVICE_0 ! \

#gst-launch-1.0 \
#	v4l2src device=$IPU2_CSI1_DEVICE ! \
#	video/x-bayer,format=rggb,depth=8,width=640,height=512 ! \
#	vita1300_remapper mode=2 passthrough=false ! \
#	bayer2rgbneon ! video/x-raw,width=640,height=512 ! \
#	videoscale ! \
#	video/x-raw,width=640,height=480 ! \
#	videoconvert ! \
#	queue ! kmssink driver-name="imx-drm" force-modesetting=false sync=true
##	fbdevsink sync=false

#	i2c addr=0x$CAM_I2C_ADRESS_1 file=`dirname $0`/../../register-settings-vita1300.txt show=0 dev=$CAM_DEVICE_1 ! \

echo 1 > /sys/class/graphics/fbcon/cursor_blink

