#!/bin/sh
. `dirname $0`/../func.sh

init_dev
[ $? -ne 0 ] && exit 1

guess_param

echo 0 > /sys/class/graphics/fbcon/cursor_blink

echo "select resolution"
echo "================="
echo "1 = 1280 x 1024 Fullframe (with gstreamer scaler artefacts)"
echo "2 = 1280 x 720 HD 720p (offset via media-ctl crop-parameter)"
echo "3 = 640 x 480 VGA with sensor-skip-mode(skip 640x512, set via v4l2-ctl)"
echo "4 = 800 x 480 WVGA with sensor-roi-mode (offset via media-ctl crop-parameter)"
read RESOLUTION
echo "Your select = $RESOLUTION"
case $RESOLUTION in
  "1") GRAB_RES="1280x1024"; FRAME_SIZE=",width=1280,height=1024"; SCALE_SIZE=",width=600,height=480"; OFFSET_SENSOR="0,0"; SUBSAMPLING="0"; REMAPPER_MODE="mode=0"; KMS_SYNC="false" ;;
  "2") GRAB_RES="1280x720"; FRAME_SIZE=",width=1280,height=720"; SCALE_SIZE=",width=800,height=450"; OFFSET_SENSOR="0,152"; SUBSAMPLING="0"; REMAPPER_MODE="mode=0"; KMS_SYNC="false" ;;
  "3") GRAB_RES="640x512"; FRAME_SIZE=",width=640,height=512"; SCALE_SIZE=",width=640,height=480"; OFFSET_SENSOR="0,0"; SUBSAMPLING="1"; REMAPPER_MODE="mode=2"; KMS_SYNC="true" ;;
  "4") GRAB_RES="800x480"; FRAME_SIZE=",width=800,height=480"; SCALE_SIZE=",width=800,height=480"; OFFSET_SENSOR="240,272"; SUBSAMPLING="0"; REMAPPER_MODE="mode=0"; KMS_SYNC="true" ;;
  *) GRAB_RES="1280x1024"; FRAME_SIZE=",width=1280,height=1024"; SCALE_SIZE=",width=640,height=480"; OFFSET_SENSOR="0,0"; SUBSAMPLING="0"; REMAPPER_MODE="mode=0"; KMS_SYNC="true" ;;
esac

echo "starting gstreamer with $CAM_COL_FMT Source ..."
echo "read $FRAME_SIZE (offset x,y=$OFFSET_SENSOR) and write scaled to framebuffer $SCALE_SIZE"
echo "=============================================================="
echo ""
echo "configure IPU1_CSI0 (camera_0 port) with media_control"
echo "======================================================"

media-ctl -r
media-ctl -l ''$CAM_ENTITY_NUMBER'0->"ipu1_csi0_mux":1[1]'
media-ctl -l "'ipu1_csi0_mux':2->'ipu1_csi0':0[1]"
media-ctl -l "'ipu1_csi0':2->'ipu1_csi0 capture':0[1]"
#           Camera -> IPU1_CSI0_mux -> IPU1-CSI0 -> IPU1-CSI0 capture (/dev/videoX)

v4l2-ctl -d $IPU1_CSI0_DEVICE -c subsampling=$SUBSAMPLING
# Note: Set subsampling is necessary before set resolution

media-ctl -V ''$CAM_ENTITY_NUMBER'0 [fmt:SRGGB8_1X8/'$GRAB_RES' crop:('$OFFSET_SENSOR')/'$GRAB_RES']'
media-ctl -V '"ipu1_csi0_mux":2 [fmt:SRGGB8_1X8/'$GRAB_RES']'
media-ctl -V '"ipu1_csi0":2 [fmt:SRGGB8_1X8/'$GRAB_RES']'

echo ""
echo "start gstreamer, break with ctl-C"
echo "================================="

gst-launch-1.0 \
	v4l2src device=$IPU1_CSI0_DEVICE ! \
	video/x-$COL_FORMAT,depth=8$FRAME_SIZE ! \
	vita1300_remapper $REMAPPER_MODE passthrough=false ! \
	bayer2rgbneon ! \
	video/x-raw$FRAME_SIZE ! \
	videoscale ! \
	video/x-raw$SCALE_SIZE ! \
	queue ! kmssink driver-name="imx-drm" force-modesetting=false sync=$KMS_SYNC
#	fbdevsink sync=false

echo 1 > /sys/class/graphics/fbcon/cursor_blink

#	Use the i2s plugin only for special register settings, that are not available through v4l2_control.
#	i2c file=`dirname $0`/../register-settings-vita1300.txt show=0 dev=$CAM_DEVICE ! \